@@ -1,12 +1,12 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
 #   copyright and license terms.
 #
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""Metadata extractor for Datalad's own core storage"""
+"""Metadata extractor for DataLad's own core storage"""
 
 from datalad.metadata.extractors.base import BaseMetadataExtractor
 
@@ -62,7 +62,8 @@ class MetadataExtractor(BaseMetadataExtractor):
                 dataset=self.ds,
                 recursive=False,
                 return_type='generator',
-                result_renderer='disabled')
+                result_renderer='disabled',
+                on_failure='ignore')
         ]
         if subdsinfo:
             obj['haspart'] = subdsinfo
